rm(list=ls())#used to clear Global environment
#data is loaded.
Aquaponic_metadata <- read.csv("C:/Users/Model Nitrogen/Desktop/MetaR/APY_SD.csv")
#changing sample sizes from integer to numeric
Aquaponic_metadata$n1i<-as.numeric(Aquaponic_metadata$n1i)
Aquaponic_metadata$n2i<-as.numeric(Aquaponic_metadata$n2i)
#calling the structure of the dataframe to make sure numeric conversion 
#is effected
str(Aquaponic_metadata)
#loading the library metafor. Make sure you have metafor installed
#before loading it.
library(metafor)
#Calculate the effect size
APmet <- escalc(measure = "ROM", m1i = m2i, m2i = m1i, 
                         sd1i = sd2i, 
                         sd2i = sd1i, 
                         n1i = n2i, n2i = n1i,
                         data = Aquaponic_metadata)
#Conduct the meta-analysis
resultAP=rma(yi, vi, data=APmet, method="REML", weighted = F)
#Make a forest plot
forest(resultAP, slab=paste(APmet$study, APmet$year), cex = 0.6)
#Make a funnel plot to examine heterogeneity and publication bias
funnel(APmet$yi, yaxis="ni", data=APmet)
#calculate fail-safe number
fsn(yi, vi, data=APmet)
#Moderator analysis using metafor
Crop<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$Crop)
Protein<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$X.protein)
density<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$mean.fish.stocking.density..kg.m3.)
NutSup<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$Nut.Sup)
Fish<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$Fish.aquatic.species)
Fish.Nut<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$Fish.aquatic.species*APmet$Nut.Sup)          
HPS<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$HP.system)
Growmedia<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$Growmedia)
edib<-rma(yi, vi, data=APmet, method="REML", weighted = F, mods = ~APmet$edib.Part, intercept = F)
#meta-regression was conducted using the meta package. Make sure meta package is installed
#then, load library
library(meta)
#You need to conduct a meta-anlysis before the meta-regression
APMeta<-metacont(mean.e = m2i, mean.c = m1i, sd.e = sd2i, sd.c = sd1i, 
                n.e = n2i, n.c =  n1i, sm = "ROM",method.tau = "REML", data = Aquaponic_metadata)
#just examining the forest plot. 
forest(APMeta, backtransf=FALSE, cex=0.3)
#Use the byvar function to specify the moderator
density <- update(APMeta, byvar = Aquaponic_metadata$mean.fish.stocking.density..kg.m3., tau.common = TRUE, comb.fixed = FALSE)
#use the bubble function to plot the meta-regression
#the meta-reg function does the meta-regression
bubble(metareg(APMeta, ~mean.fish.stocking.density..kg.m3.), 
       ylab = "log ratio of means",
       xlab = expression('Fish mean stocking density (kg m'^-3*')'),
       ylim = c(-4,4), col.line="blue", cex="fixed", min.cex = 1.2, max.cex = 2.3)
protein<-update(APMeta, byvar = Aquaponic_metadata$X.protein, tau.common = TRUE, comb.fixed = FALSE)
bubble(metareg(APMeta, ~X.protein), 
       ylab = "log ratio of means",
       xlab = "Feed crude protein content (%)",
       ylim = c(-4,4), col.line="blue",cex="fixed", min.cex = 1.2, max.cex = 2.3)
RAS.vol<-update(APMeta, byvar = Aquaponic_metadata$RAS.volume..m3., tau.common = TRUE, comb.fixed = FALSE)
bubble(metareg(APMeta, ~RAS.volume..m3.), 
       ylab = "log ratio of means",
       xlab = expression('Volume of rearing tank (m'^3*')'),
       ylim = c(-4,4), col.line="blue",cex="fixed", min.cex = 1.2, max.cex = 2.3)
summary(metareg(APMeta, ~RAS.volume..m3.))
